set topDir charmm36

package require psfgen
package require topotools

topology $topDir/top_all36_na.rtf

pdbalias residue A ADE
pdbalias residue T THY
pdbalias residue G GUA
pdbalias residue C CYT

foreach resname {A T C G} {
    foreach direction {fwd rev} {
	foreach patch {{5TER DEO5} {DEOX} {3TER DEOX} {3TER DEO5}} mod {-5prime "" -3prime -singlet} {
	    resetpsf
	    if [string match $direction "fwd"] {
		set pdb [glob 1-w3dna/${resname}?.pdb]
	    } else {
		set pdb [glob 1-w3dna/?${resname}.pdb]
	    }

	    set ID [mol new $pdb]
	    
	    set sel [atomselect top "resname $resname"]
	    set seg A
	    $sel set segid $seg
	    $sel writepdb tmp.pdb
	
	    segment $seg { pdb tmp.pdb }

	    set resids [$sel get resid]
	    foreach p $patch {
		patch $p $seg:[lindex $resids 0]
	    }
	    regenerate angles dihedrals

	    coordpdb tmp.pdb

	    guesscoord
	    set out $resname-$direction$mod
	    writepsf $out.psf
	    writepdb $out.pdb

	    mol delete $ID
	    set ID [mol new $out.psf]
	    mol addfile $out.pdb
	    set sel [atomselect $ID all]

	    ## write coordinates
	    set ch [open ../$out.dat w]
	    foreach r [$sel get {index name type charge mass x y z}] {
		puts $ch $r
	    }
	    close $ch

	    ## write bonds
	    set ch [open ../$out.bonds.txt w]
	    puts $ch [join [topo getbondlist none]]
	    close $ch
	    ## write angles
	    set ch [open ../$out.angles.txt w]
	    puts $ch [string map {"unknown " ""} [join [topo getanglelist $sel]]]
	    close $ch

	    ## write dihedrals
	    set ch [open ../$out.dihedrals.txt w]
	    puts $ch [string map {"unknown " ""} [join [topo getdihedrallist $sel]]]
	    close $ch

	    ## write exclusions
	    set ch [open ../$out.impropers.txt w]
	    puts $ch [string map {"unknown " ""} [join [topo getimproperlist $sel]]]
	    close $ch

	    mol delete $ID
	}
    }
}
